@@ -18,12 +18,16 @@
 #define VK_TIMEOUT    0x1001
 #define VK_REDRAW     0x1002
 
+#define TIMEOUT_TIMER_ID 1
+
 struct glyph
 {
-	unsigned int id;
-	HDC dc;
-	HBITMAP bitmap;
-	int width;
+	unsigned int id;              /* id of this glyph */
+	HDC dc;                       /* Memory DC this glyph is drawn to */
+	HBITMAP bitmap;               /* Backing store for memory DC */
+	int width;                    /* Width of cell for this glyph */
+	int xoffset, yoffset;         /* Draw offset */
+	int realwidth, realheight;    /* Actual size of glyph bitmap */
 	UT_hash_handle hh;
 };
 
@@ -37,4 +41,6 @@ extern struct glyph* glyphcache_getglyph(unsigned int id, HDC dc);
 extern void dpy_queuekey(uni_t key);
 extern void dpy_flushkeys(void);
 
+extern HWND window;
+
 #endif
