@@ -1,9 +1,6 @@
 /* © 2008 David Given.
  * WordGrinder is licensed under the MIT open source license. See the COPYING
  * file in this distribution for the full text.
- *
- * $Id: main.c 159 2009-12-13 13:11:03Z dtrg $
- * $URL: https://wordgrinder.svn.sf.net/svnroot/wordgrinder/wordgrinder/src/c/main.c $
  */
 
 #include <stdlib.h>
@@ -18,8 +15,8 @@ int main(int argc, const char* argv[])
 	script_init();
 	screen_init(argv);
 	word_init();
-	bit_init();
 	utils_init();
+	zip_init();
 
 	script_load_from_table(script_table);
 	script_run(argv);
