@@ -1,14 +1,11 @@
 -- © 2008 David Given.
 -- WordGrinder is licensed under the MIT open source license. See the COPYING
 -- file in this distribution for the full text.
---
--- $Id: _prologue.lua 159 2009-12-13 13:11:03Z dtrg $
--- $URL: https://wordgrinder.svn.sf.net/svnroot/wordgrinder/wordgrinder/src/lua/_prologue.lua $
 
 -- Load the LFS module if needed (Windows has it built in).
 
 if not lfs then
-	require "lfs"
+	lfs = require "lfs"
 end
 
 -- Global definitions that the various source files need.
