@@ -2,8 +2,6 @@
 -- WordGrinder is licensed under the MIT open source license. See the COPYING
 -- file in this distribution for the full text.
 
-local ITALIC = wg.ITALIC
-local UNDERLINE = wg.UNDERLINE
 local ParseWord = wg.parseword
 local bitand = bit32.band
 local bitor = bit32.bor
@@ -25,6 +23,8 @@ local BOOLEANFALSE = 3
 local STRING = 4
 local NUMBER = 5
 local CACHE = 6
+local NEGNUMBER = 7
+local BRIEFWORD = 8
 
 local DOCUMENTSETCLASS = 100
 local DOCUMENTCLASS = 101
@@ -59,19 +59,24 @@ local function writetostream(object, writes, writei)
 			else
 				m = TABLE
 			end
-			writei(m)
-			writei(#t)
-			
-			for _, i in ipairs(t) do
-				save(i)
-			end
-			for k, v in pairs(t) do
-				if (type(k) ~= "number") then
-					save(k)
-					save(v)
+			if (m == WORDCLASS) then
+				writei(BRIEFWORD)
+				save(t.text)
+			else
+				writei(m)
+				writei(#t)
+				
+				for _, i in ipairs(t) do
+					save(i)
 				end
+				for k, v in pairs(t) do
+					if (type(k) ~= "number") then
+						save(k)
+						save(v)
+					end
+				end
+				writei(STOP)
 			end
-			writei(STOP)
 		elseif (type(t) == "boolean") then
 			if t then
 				writei(BOOLEANTRUE)
@@ -83,8 +88,13 @@ local function writetostream(object, writes, writei)
 			writei(#t)
 			writes(t)
 		elseif (type(t) == "number") then
-			writei(NUMBER)
-			writei(t)
+			if (t >= 0) then
+				writei(NUMBER)
+				writei(t)
+			else
+				writei(NEGNUMBER)
+				writei(-t)
+			end
 		else
 			error("unsupported type "..type(t))
 		end
@@ -133,6 +143,9 @@ function Cmd.SaveCurrentDocumentAs(filename)
 		if not filename then
 			return false
 		end
+		if filename:find("/[^.]*$") then
+			filename = filename .. ".wg"
+		end
 	end
 	DocumentSet.name = filename
 
@@ -154,6 +167,9 @@ function Cmd.SaveCurrentDocument()
 		if not name then
 			return false
 		end
+		if name:find("/[^.]*$") then
+			name = name .. ".wg"
+		end
 		DocumentSet.name = name
 	end
 	
@@ -329,6 +345,14 @@ local function loadfromstreamz(fp)
 			return populate_table(t)
 		end,
 		
+		[BRIEFWORD] = function()
+			local t = {}
+			setmetatable(t, {__index = WordClass})
+			cache[#cache + 1] = t
+			t.text = load()
+			return t
+		end,
+		
 		[MENUCLASS] = function()
 			local t = {}
 			setmetatable(t, {__index = MenuClass})
@@ -359,6 +383,14 @@ local function loadfromstreamz(fp)
 			return n
 		end,
 		
+		[NEGNUMBER] = function()
+			local n
+			n, offset = readu8(data, offset)
+			n = -n
+			cache[#cache + 1] = n
+			return n
+		end,
+		
 		[BOOLEANTRUE] = function()
 			cache[#cache + 1] = true
 			return true
