@@ -7,6 +7,7 @@ local ClearToEOL = wg.cleartoeol
 local GetChar = wg.getchar
 local GotoXY = wg.gotoxy
 local SetBold = wg.setbold
+local SetBright = wg.setbright
 local SetReverse = wg.setreverse
 local SetNormal = wg.setnormal
 local GetStringWidth = wg.getstringwidth
@@ -90,13 +91,16 @@ local ExportMenu = addmenu("Export current document",
 	{"FEtxt",  "T", "Export to plain text...",   nil,         Cmd.ExportTextFile},
 	{"FEtex",  "L", "Export to LaTeX...",        nil,         Cmd.ExportLatexFile},
 	{"FEtr",   "F", "Export to Troff...",        nil,         Cmd.ExportTroffFile},
+--	{"FErtf",  "R", "Export to Rtf...",        nil,         Cmd.ExportRTFFile},
 })
 
 local SettingsMenu = addmenu("Settings",
 {
     {"FSautosave", "A", "Autosave...",               nil,         Cmd.ConfigureAutosave},
     {"FSscrapbook", "S", "Scrapbook...",             nil,         Cmd.ConfigureScrapbook},
-    {"FHTMLExport", "H", "HTML export...",           nil,         Cmd.ConfigureHTMLExport},
+    {"FSHTMLExport", "H", "HTML export...",          nil,         Cmd.ConfigureHTMLExport},
+	{"FSPageCount", "P", "Page count...",            nil,         Cmd.ConfigurePageCount},
+	{"FSWidescreen", "W", "Widescreen mode...",      nil,         Cmd.ConfigureWidescreen},ConfigureWidescreen
 })
 
 local FileMenu = addmenu("File",
@@ -141,20 +145,21 @@ local EditMenu = addmenu("Edit",
 
 local MarginMenu = addmenu("Margin",
 {
-	{"SM1",    "H", "Hide margin",                nil,          function() Cmd.SetViewMode(1) end},
-	{"SM2",    "S", "Show paragraph styles",      nil,          function() Cmd.SetViewMode(2) end},
-	{"SM3",    "N", "Show paragraph numbers",     nil,          function() Cmd.SetViewMode(3) end},
+	{"SM1",    "H", "Hide margin",                nil,         function() Cmd.SetViewMode(1) end},
+	{"SM2",    "S", "Show paragraph styles",      nil,         function() Cmd.SetViewMode(2) end},
+	{"SM3",    "N", "Show paragraph numbers",     nil,         function() Cmd.SetViewMode(3) end},
 	{"SM4",    "W", "Show paragraph word counts", nil,         function() Cmd.SetViewMode(4) end},
 })
 	
 local StyleMenu = addmenu("Style",
 {
-	{"SB",     "I", "Set italic",                 "^I",        function() Cmd.ToggleStyle("i") end},
+	{"SI",     "I", "Set italic",                 "^I",        function() Cmd.ToggleStyle("i") end},
 	{"SU",     "U", "Set underline",              "^U",        function() Cmd.ToggleStyle("u") end},
+	{"SB",     "B", "Set bold",                   "^B",        function() Cmd.ToggleStyle("b") end},
 	{"SO",     "O", "Set plain",                  "^O",        function() Cmd.ToggleStyle("o") end},
 	"-",
 	{"SP",     "P", "Change paragraph style ▷",   "^P",        ParagraphStylesMenu},
-	{"SM",     "M", "Set margin mode ▷",          nil,          MarginMenu},
+	{"SM",     "M", "Set margin mode ▷",          nil,         MarginMenu},
 	{"SS",     "S", "Toggle status bar",          "^W",        Cmd.ToggleStatusBar},
 })
 
@@ -214,9 +219,7 @@ MenuClass = {
 		end
 		
 		local w = menu.maxwidth + 4 + akw
-		SetBold()
 		DrawTitledBox(x, y, w, #menu, menu.label)
-		SetNormal()
 		
 		for i, item in ipairs(menu) do
 			local ak = self.accelerators[item.id]
@@ -225,6 +228,7 @@ MenuClass = {
 				if (i == n) then
 					SetReverse()
 				end
+				SetBright()
 				Write(x+1, y+i, string.rep("─", w))
 			else
 				if (i == n) then
@@ -233,14 +237,15 @@ MenuClass = {
 				end
 				
 				Write(x+4, y+i, item.label)
+
+				SetBold()
+				SetBright()
 				if ak then
 					local l = GetStringWidth(ak)
-					SetBold()
 					Write(x+w-l, y+i, ak)
 				end
 		
 				if item.mk then
-					SetBold()
 					Write(x+2, y+i, item.mk)
 				end
 			end
@@ -287,7 +292,9 @@ MenuClass = {
 				elseif (c == "KEY_LEFT") then
 					return nil
 				elseif (c == "KEY_ESCAPE") then
-					return nil
+					return false
+				elseif (c == "KEY_^C") then
+					return false
 				elseif (c == "KEY_^X") then
 					local item = menu[n]
 					if (type(item) ~= "string") then
@@ -345,6 +352,8 @@ MenuClass = {
 				}
 				
 				local r = self:runmenu(x+4, y+2, f)
+				menu_stack[#menu_stack] = nil
+
 				if (r == true) then
 					return true
 				elseif (r == false) then
@@ -352,7 +361,6 @@ MenuClass = {
 				end
 				
 				self:drawmenustack()
-				menu_stack[#menu_stack] = nil
 			else
 				if not f then
 					ModalMessage("Not implemented yet", "Sorry, that feature isn't implemented yet. (This should never happen. Complain.)")
